@@ -42,9 +42,10 @@ sub remove
 	}
 	if ( defined $found) {
 		splice( @$q, $found, 1);
-		$self-> release unless @$q; 
+		return 1;
 	} else {
 		warn "$self failed to remove $lambda from queue\n" if $DEBUG;
+		return 0;
 	}
 }
 
@@ -63,7 +64,10 @@ sub waiter
 	my $bind   = $waiter-> bind( sub {
 		my ($w,$rec) = (shift,shift);
 		# lambda was terminated, relinquish waiting and kill timeout
-		$self-> remove($w);
+		unless ($w->{__already_removed}) {
+			my $removed = $self->remove($w);
+			$self->release if !$removed && 0 == $self->{queue};
+		}
 		$w-> cancel_event($timeout) if defined $timeout;
 		return @_; # propagate error
 	});
@@ -92,6 +96,7 @@ sub release
 	my $lambda = shift @{$self-> {queue}};
 
 	warn "$self gives ownership to $lambda\n" if $DEBUG;
+	$lambda-> {__already_removed} = 1;
 	$lambda-> terminate(undef);
 }
 
@@ -174,7 +179,18 @@ that in turn will finish as soon as the caller can acquire the mutex.
             # expected to be 'ok'
 	}
     }->wait;
-    
+
+    # pipeline -  manage a queue of lambdas, stuff new ones to it, guarantees
+    # sequential execution:
+    lambda {
+        context 
+            $mutex-> pipeline( lambda { print 1 } ),
+            $mutex-> pipeline( lambda { print 2 } ),
+            $mutex-> pipeline( lambda { print 3 } )
+        ;
+        &tails();
+    }-> wait;
+    # prints 123 guaranteedly in that order, even if intermediate lambdas sleep etc
 
 =head1 API
 
@@ -218,11 +234,11 @@ the mutex was acquired successfully, or the error string.
 
 If C<$timeout> is defined, and by the time it is expired the mutex
 could not be obtained, the lambda is removed from the queue, and
-returned error value is 'timeout'.
+returned error value is 'timeout'. The mutex state is then unchanged.
 
-Note, that after C<waiter> succeeds, a C<release> call is needed
-should mutex be reused. See C<pipeline> method for automatic mutex
-release.
+If C<waiter> succeeds, a C<release> call is issued. Thus, if the next 
+waiter awaits for the mutex, it will be notified; otherwise the mutex
+becomes free.
 
 =item pipeline($lambda, $timeout = undef)
 
