@@ -1,4 +1,4 @@
-# $Id: Thread.pm,v 1.24 2009/12/04 22:11:31 dk Exp $
+# $Id: Thread.pm,v 1.25 2010/03/27 19:51:24 dk Exp $
 package IO::Lambda::Thread;
 use base qw(IO::Lambda);
 use strict;
@@ -11,6 +11,8 @@ use IO::Lambda qw(:all :dev swap_frame);
 our $DISABLED;
 eval { require threads; };
 $DISABLED = $@ if $@;
+$DISABLED = "broken threads on this perl version" if
+	!defined $DISABLED && $^O =~ /win32/i && $] < 5.020;
 
 our $DEBUG = $IO::Lambda::DEBUG{thread};
 
@@ -149,7 +151,7 @@ threads. The socket can be also used by the caller for its own needs, if necessa
 
     lambda {
         context 0.1, threaded {
-	      select(undef,undef,undef,0.8);
+	      sleep(1);
 	      return "hello!";
 	};
         any_tail {
